<?php

return [
    'Names' => [
        'ADP' => [
            0 => 'ADP',
            1 => 'Andorrese peseta',
        ],
        'AED' => [
            0 => 'AED',
            1 => 'Verenigde Arabische Emiraten-dirham',
        ],
        'AFA' => [
            0 => 'AFA',
            1 => 'Afghani (1927–2002)',
        ],
        'AFN' => [
            0 => 'AFN',
            1 => 'Afghaanse afghani',
        ],
        'ALK' => [
            0 => 'ALK',
            1 => 'Albanese lek (1946–1965)',
        ],
        'ALL' => [
            0 => 'ALL',
            1 => 'Albanese lek',
        ],
        'AMD' => [
            0 => 'AMD',
            1 => 'Armeense dram',
        ],
        'ANG' => [
            0 => 'ANG',
            1 => 'Nederlands-Antilliaanse gulden',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'Angolese kwanza',
        ],
        'AOK' => [
            0 => 'AOK',
            1 => 'Angolese kwanza (1977–1990)',
        ],
        'AON' => [
            0 => 'AON',
            1 => 'Angolese nieuwe kwanza (1990–2000)',
        ],
        'AOR' => [
            0 => 'AOR',
            1 => 'Angolese kwanza reajustado (1995–1999)',
        ],
        'ARA' => [
            0 => 'ARA',
            1 => 'Argentijnse austral',
        ],
        'ARL' => [
            0 => 'ARL',
            1 => 'Argentijnse peso ley (1970–1983)',
        ],
        'ARM' => [
            0 => 'ARM',
            1 => 'Argentijnse peso (1881–1970)',
        ],
        'ARP' => [
            0 => 'ARP',
            1 => 'Argentijnse peso (1983–1985)',
        ],
        'ARS' => [
            0 => 'ARS',
            1 => 'Argentijnse peso',
        ],
        'ATS' => [
            0 => 'ATS',
            1 => 'Oostenrijkse schilling',
        ],
        'AUD' => [
            0 => 'AU$',
            1 => 'Australische dollar',
        ],
        'AWG' => [
            0 => 'AWG',
            1 => 'Arubaanse gulden',
        ],
        'AZM' => [
            0 => 'AZM',
            1 => 'Azerbeidzjaanse manat (1993–2006)',
        ],
        'AZN' => [
            0 => 'AZN',
            1 => 'Azerbeidzjaanse manat',
        ],
        'BAD' => [
            0 => 'BAD',
            1 => 'Bosnische dinar',
        ],
        'BAM' => [
            0 => 'BAM',
            1 => 'Bosnische convertibele mark',
        ],
        'BAN' => [
            0 => 'BAN',
            1 => 'Nieuwe Bosnische dinar (1994–1997)',
        ],
        'BBD' => [
            0 => 'BBD',
            1 => 'Barbadaanse dollar',
        ],
        'BDT' => [
            0 => 'BDT',
            1 => 'Bengalese taka',
        ],
        'BEC' => [
            0 => 'BEC',
            1 => 'Belgische frank (convertibel)',
        ],
        'BEF' => [
            0 => 'BEF',
            1 => 'Belgische frank',
        ],
        'BEL' => [
            0 => 'BEL',
            1 => 'Belgische frank (financieel)',
        ],
        'BGL' => [
            0 => 'BGL',
            1 => 'Bulgaarse harde lev',
        ],
        'BGM' => [
            0 => 'BGM',
            1 => 'Bulgaarse socialistische lev',
        ],
        'BGN' => [
            0 => 'BGN',
            1 => 'Bulgaarse lev',
        ],
        'BGO' => [
            0 => 'BGO',
            1 => 'Bulgaarse lev (1879–1952)',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'Bahreinse dinar',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'Burundese frank',
        ],
        'BMD' => [
            0 => 'BMD',
            1 => 'Bermuda-dollar',
        ],
        'BND' => [
            0 => 'BND',
            1 => 'Bruneise dollar',
        ],
        'BOB' => [
            0 => 'BOB',
            1 => 'Boliviaanse boliviano',
        ],
        'BOL' => [
            0 => 'BOL',
            1 => 'Boliviaanse boliviano (1863–1963)',
        ],
        'BOP' => [
            0 => 'BOP',
            1 => 'Boliviaanse peso',
        ],
        'BOV' => [
            0 => 'BOV',
            1 => 'Boliviaanse mvdol',
        ],
        'BRB' => [
            0 => 'BRB',
            1 => 'Braziliaanse cruzeiro novo (1967–1986)',
        ],
        'BRC' => [
            0 => 'BRC',
            1 => 'Braziliaanse cruzado',
        ],
        'BRE' => [
            0 => 'BRE',
            1 => 'Braziliaanse cruzeiro (1990–1993)',
        ],
        'BRL' => [
            0 => 'R$',
            1 => 'Braziliaanse real',
        ],
        'BRN' => [
            0 => 'BRN',
            1 => 'Braziliaanse nieuwe cruzado (1989–1990)',
        ],
        'BRR' => [
            0 => 'BRR',
            1 => 'Braziliaanse cruzeiro',
        ],
        'BRZ' => [
            0 => 'BRZ',
            1 => 'Braziliaanse cruzeiro (1942–1967)',
        ],
        'BSD' => [
            0 => 'BSD',
            1 => 'Bahamaanse dollar',
        ],
        'BTN' => [
            0 => 'BTN',
            1 => 'Bhutaanse ngultrum',
        ],
        'BUK' => [
            0 => 'BUK',
            1 => 'Birmese kyat',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'Botswaanse pula',
        ],
        'BYB' => [
            0 => 'BYB',
            1 => 'Wit-Russische nieuwe roebel (1994–1999)',
        ],
        'BYN' => [
            0 => 'BYN',
            1 => 'Belarussische roebel',
        ],
        'BYR' => [
            0 => 'BYR',
            1 => 'Wit-Russische roebel (2000–2016)',
        ],
        'BZD' => [
            0 => 'BZD',
            1 => 'Belizaanse dollar',
        ],
        'CAD' => [
            0 => 'C$',
            1 => 'Canadese dollar',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'Congolese frank',
        ],
        'CHE' => [
            0 => 'CHE',
            1 => 'WIR euro',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'Zwitserse frank',
        ],
        'CHW' => [
            0 => 'CHW',
            1 => 'WIR franc',
        ],
        'CLE' => [
            0 => 'CLE',
            1 => 'Chileense escudo',
        ],
        'CLF' => [
            0 => 'CLF',
            1 => 'Chileense unidades de fomento',
        ],
        'CLP' => [
            0 => 'CLP',
            1 => 'Chileense peso',
        ],
        'CNH' => [
            0 => 'CNH',
            1 => 'Chinese yuan (offshore)',
        ],
        'CNX' => [
            0 => 'CNX',
            1 => 'dollar van de Chinese Volksbank',
        ],
        'CNY' => [
            0 => 'CN¥',
            1 => 'Chinese yuan',
        ],
        'COP' => [
            0 => 'COP',
            1 => 'Colombiaanse peso',
        ],
        'COU' => [
            0 => 'COU',
            1 => 'Unidad de Valor Real',
        ],
        'CRC' => [
            0 => 'CRC',
            1 => 'Costa Ricaanse colon',
        ],
        'CSD' => [
            0 => 'CSD',
            1 => 'Oude Servische dinar',
        ],
        'CSK' => [
            0 => 'CSK',
            1 => 'Tsjechoslowaakse harde koruna',
        ],
        'CUC' => [
            0 => 'CUC',
            1 => 'Cubaanse convertibele peso',
        ],
        'CUP' => [
            0 => 'CUP',
            1 => 'Cubaanse peso',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'Kaapverdische escudo',
        ],
        'CYP' => [
            0 => 'CYP',
            1 => 'Cyprisch pond',
        ],
        'CZK' => [
            0 => 'CZK',
            1 => 'Tsjechische kroon',
        ],
        'DDM' => [
            0 => 'DDM',
            1 => 'Oost-Duitse ostmark',
        ],
        'DEM' => [
            0 => 'DEM',
            1 => 'Duitse mark',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'Djiboutiaanse frank',
        ],
        'DKK' => [
            0 => 'DKK',
            1 => 'Deense kroon',
        ],
        'DOP' => [
            0 => 'DOP',
            1 => 'Dominicaanse peso',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'Algerijnse dinar',
        ],
        'ECS' => [
            0 => 'ECS',
            1 => 'Ecuadoraanse sucre',
        ],
        'ECV' => [
            0 => 'ECV',
            1 => 'Ecuadoraanse unidad de valor constante (UVC)',
        ],
        'EEK' => [
            0 => 'EEK',
            1 => 'Estlandse kroon',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'Egyptisch pond',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'Eritrese nakfa',
        ],
        'ESA' => [
            0 => 'ESA',
            1 => 'Spaanse peseta (account A)',
        ],
        'ESB' => [
            0 => 'ESB',
            1 => 'Spaanse peseta (convertibele account)',
        ],
        'ESP' => [
            0 => 'ESP',
            1 => 'Spaanse peseta',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'Ethiopische birr',
        ],
        'EUR' => [
            0 => '€',
            1 => 'Euro',
        ],
        'FIM' => [
            0 => 'FIM',
            1 => 'Finse markka',
        ],
        'FJD' => [
            0 => 'FJ$',
            1 => 'Fiji-dollar',
        ],
        'FKP' => [
            0 => 'FKP',
            1 => 'Falklandeilands pond',
        ],
        'FRF' => [
            0 => 'FRF',
            1 => 'Franse franc',
        ],
        'GBP' => [
            0 => '£',
            1 => 'Britse pond',
        ],
        'GEK' => [
            0 => 'GEK',
            1 => 'Georgische kupon larit',
        ],
        'GEL' => [
            0 => 'GEL',
            1 => 'Georgische lari',
        ],
        'GHC' => [
            0 => 'GHC',
            1 => 'Ghanese cedi (1979–2007)',
        ],
        'GHS' => [
            0 => 'GHS',
            1 => 'Ghanese cedi',
        ],
        'GIP' => [
            0 => 'GIP',
            1 => 'Gibraltarees pond',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'Gambiaanse dalasi',
        ],
        'GNF' => [
            0 => 'GNF',
            1 => 'Guinese frank',
        ],
        'GNS' => [
            0 => 'GNS',
            1 => 'Guinese syli',
        ],
        'GQE' => [
            0 => 'GQE',
            1 => 'Equatoriaal-Guinese ekwele guineana',
        ],
        'GRD' => [
            0 => 'GRD',
            1 => 'Griekse drachme',
        ],
        'GTQ' => [
            0 => 'GTQ',
            1 => 'Guatemalteekse quetzal',
        ],
        'GWE' => [
            0 => 'GWE',
            1 => 'Portugees-Guinese escudo',
        ],
        'GWP' => [
            0 => 'GWP',
            1 => 'Guinee-Bissause peso',
        ],
        'GYD' => [
            0 => 'GYD',
            1 => 'Guyaanse dollar',
        ],
        'HKD' => [
            0 => 'HK$',
            1 => 'Hongkongse dollar',
        ],
        'HNL' => [
            0 => 'HNL',
            1 => 'Hondurese lempira',
        ],
        'HRD' => [
            0 => 'HRD',
            1 => 'Kroatische dinar',
        ],
        'HRK' => [
            0 => 'HRK',
            1 => 'Kroatische kuna',
        ],
        'HTG' => [
            0 => 'HTG',
            1 => 'Haïtiaanse gourde',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => 'Hongaarse forint',
        ],
        'IDR' => [
            0 => 'IDR',
            1 => 'Indonesische roepia',
        ],
        'IEP' => [
            0 => 'IEP',
            1 => 'Iers pond',
        ],
        'ILP' => [
            0 => 'ILP',
            1 => 'Israëlisch pond',
        ],
        'ILR' => [
            0 => 'ILR',
            1 => 'Israëlische sjekel (1980–1985)',
        ],
        'ILS' => [
            0 => '₪',
            1 => 'Israëlische nieuwe shekel',
        ],
        'INR' => [
            0 => '₹',
            1 => 'Indiase roepie',
        ],
        'IQD' => [
            0 => 'IQD',
            1 => 'Iraakse dinar',
        ],
        'IRR' => [
            0 => 'IRR',
            1 => 'Iraanse rial',
        ],
        'ISJ' => [
            0 => 'ISJ',
            1 => 'IJslandse kroon (1918–1981)',
        ],
        'ISK' => [
            0 => 'ISK',
            1 => 'IJslandse kroon',
        ],
        'ITL' => [
            0 => 'ITL',
            1 => 'Italiaanse lire',
        ],
        'JMD' => [
            0 => 'JMD',
            1 => 'Jamaicaanse dollar',
        ],
        'JOD' => [
            0 => 'JOD',
            1 => 'Jordaanse dinar',
        ],
        'JPY' => [
            0 => 'JP¥',
            1 => 'Japanse yen',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'Keniaanse shilling',
        ],
        'KGS' => [
            0 => 'KGS',
            1 => 'Kirgizische som',
        ],
        'KHR' => [
            0 => 'KHR',
            1 => 'Cambodjaanse riel',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'Comorese frank',
        ],
        'KPW' => [
            0 => 'KPW',
            1 => 'Noord-Koreaanse won',
        ],
        'KRH' => [
            0 => 'KRH',
            1 => 'Zuid-Koreaanse hwan (1953–1962)',
        ],
        'KRO' => [
            0 => 'KRO',
            1 => 'Oude Zuid-Koreaanse won (1945–1953)',
        ],
        'KRW' => [
            0 => '₩',
            1 => 'Zuid-Koreaanse won',
        ],
        'KWD' => [
            0 => 'KWD',
            1 => 'Koeweitse dinar',
        ],
        'KYD' => [
            0 => 'KYD',
            1 => 'Kaaimaneilandse dollar',
        ],
        'KZT' => [
            0 => 'KZT',
            1 => 'Kazachse tenge',
        ],
        'LAK' => [
            0 => 'LAK',
            1 => 'Laotiaanse kip',
        ],
        'LBP' => [
            0 => 'LBP',
            1 => 'Libanees pond',
        ],
        'LKR' => [
            0 => 'LKR',
            1 => 'Sri Lankaanse roepie',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'Liberiaanse dollar',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'Lesothaanse loti',
        ],
        'LTL' => [
            0 => 'LTL',
            1 => 'Litouwse litas',
        ],
        'LTT' => [
            0 => 'LTT',
            1 => 'Litouwse talonas',
        ],
        'LUC' => [
            0 => 'LUC',
            1 => 'Luxemburgse convertibele franc',
        ],
        'LUF' => [
            0 => 'LUF',
            1 => 'Luxemburgse frank',
        ],
        'LUL' => [
            0 => 'LUL',
            1 => 'Luxemburgse financiële franc',
        ],
        'LVL' => [
            0 => 'LVL',
            1 => 'Letse lats',
        ],
        'LVR' => [
            0 => 'LVR',
            1 => 'Letse roebel',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'Libische dinar',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'Marokkaanse dirham',
        ],
        'MAF' => [
            0 => 'MAF',
            1 => 'Marokkaanse franc',
        ],
        'MCF' => [
            0 => 'MCF',
            1 => 'Monegaskische frank',
        ],
        'MDC' => [
            0 => 'MDC',
            1 => 'Moldavische cupon',
        ],
        'MDL' => [
            0 => 'MDL',
            1 => 'Moldavische leu',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'Malagassische ariary',
        ],
        'MGF' => [
            0 => 'MGF',
            1 => 'Malagassische franc',
        ],
        'MKD' => [
            0 => 'MKD',
            1 => 'Macedonische denar',
        ],
        'MKN' => [
            0 => 'MKN',
            1 => 'Macedonische denar (1992–1993)',
        ],
        'MLF' => [
            0 => 'MLF',
            1 => 'Malinese franc',
        ],
        'MMK' => [
            0 => 'MMK',
            1 => 'Myanmarese kyat',
        ],
        'MNT' => [
            0 => 'MNT',
            1 => 'Mongoolse tugrik',
        ],
        'MOP' => [
            0 => 'MOP',
            1 => 'Macause pataca',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'Mauritaanse ouguiya (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'Mauritaanse ouguiya',
        ],
        'MTL' => [
            0 => 'MTL',
            1 => 'Maltese lire',
        ],
        'MTP' => [
            0 => 'MTP',
            1 => 'Maltees pond',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'Mauritiaanse roepie',
        ],
        'MVP' => [
            0 => 'MVP',
            1 => 'Maldivische roepie',
        ],
        'MVR' => [
            0 => 'MVR',
            1 => 'Maldivische rufiyaa',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'Malawische kwacha',
        ],
        'MXN' => [
            0 => 'MX$',
            1 => 'Mexicaanse peso',
        ],
        'MXP' => [
            0 => 'MXP',
            1 => 'Mexicaanse zilveren peso (1861–1992)',
        ],
        'MXV' => [
            0 => 'MXV',
            1 => 'Mexicaanse unidad de inversion (UDI)',
        ],
        'MYR' => [
            0 => 'MYR',
            1 => 'Maleisische ringgit',
        ],
        'MZE' => [
            0 => 'MZE',
            1 => 'Mozambikaanse escudo',
        ],
        'MZM' => [
            0 => 'MZM',
            1 => 'Oude Mozambikaanse metical',
        ],
        'MZN' => [
            0 => 'MZN',
            1 => 'Mozambikaanse metical',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'Namibische dollar',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'Nigeriaanse naira',
        ],
        'NIC' => [
            0 => 'NIC',
            1 => 'Nicaraguaanse córdoba (1988–1991)',
        ],
        'NIO' => [
            0 => 'NIO',
            1 => 'Nicaraguaanse córdoba',
        ],
        'NLG' => [
            0 => 'NLG',
            1 => 'Nederlandse gulden',
        ],
        'NOK' => [
            0 => 'NOK',
            1 => 'Noorse kroon',
        ],
        'NPR' => [
            0 => 'NPR',
            1 => 'Nepalese roepie',
        ],
        'NZD' => [
            0 => 'NZ$',
            1 => 'Nieuw-Zeelandse dollar',
        ],
        'OMR' => [
            0 => 'OMR',
            1 => 'Omaanse rial',
        ],
        'PAB' => [
            0 => 'PAB',
            1 => 'Panamese balboa',
        ],
        'PEI' => [
            0 => 'PEI',
            1 => 'Peruaanse inti',
        ],
        'PEN' => [
            0 => 'PEN',
            1 => 'Peruaanse sol',
        ],
        'PES' => [
            0 => 'PES',
            1 => 'Peruaanse sol (1863–1965)',
        ],
        'PGK' => [
            0 => 'PGK',
            1 => 'Papoea-Nieuw-Guinese kina',
        ],
        'PHP' => [
            0 => 'PHP',
            1 => 'Filipijnse peso',
        ],
        'PKR' => [
            0 => 'PKR',
            1 => 'Pakistaanse roepie',
        ],
        'PLN' => [
            0 => 'PLN',
            1 => 'Poolse zloty',
        ],
        'PLZ' => [
            0 => 'PLZ',
            1 => 'Poolse zloty (1950–1995)',
        ],
        'PTE' => [
            0 => 'PTE',
            1 => 'Portugese escudo',
        ],
        'PYG' => [
            0 => 'PYG',
            1 => 'Paraguayaanse guarani',
        ],
        'QAR' => [
            0 => 'QAR',
            1 => 'Qatarese rial',
        ],
        'RHD' => [
            0 => 'RHD',
            1 => 'Rhodesische dollar',
        ],
        'ROL' => [
            0 => 'ROL',
            1 => 'Oude Roemeense leu',
        ],
        'RON' => [
            0 => 'RON',
            1 => 'Roemeense leu',
        ],
        'RSD' => [
            0 => 'RSD',
            1 => 'Servische dinar',
        ],
        'RUB' => [
            0 => 'RUB',
            1 => 'Russische roebel',
        ],
        'RUR' => [
            0 => 'RUR',
            1 => 'Russische roebel (1991–1998)',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'Rwandese frank',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'Saoedi-Arabische riyal',
        ],
        'SBD' => [
            0 => 'SI$',
            1 => 'Salomon-dollar',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => 'Seychelse roepie',
        ],
        'SDD' => [
            0 => 'SDD',
            1 => 'Soedanese dinar',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'Soedanees pond',
        ],
        'SDP' => [
            0 => 'SDP',
            1 => 'Soedanees pond (1957–1998)',
        ],
        'SEK' => [
            0 => 'SEK',
            1 => 'Zweedse kroon',
        ],
        'SGD' => [
            0 => 'SGD',
            1 => 'Singaporese dollar',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'Sint-Heleens pond',
        ],
        'SIT' => [
            0 => 'SIT',
            1 => 'Sloveense tolar',
        ],
        'SKK' => [
            0 => 'SKK',
            1 => 'Slowaakse koruna',
        ],
        'SLE' => [
            0 => 'SLE',
            1 => 'Sierra Leoonse leone',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'Sierraleoonse leone (1964—2022)',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'Somalische shilling',
        ],
        'SRD' => [
            0 => 'SRD',
            1 => 'Surinaamse dollar',
        ],
        'SRG' => [
            0 => 'SRG',
            1 => 'Surinaamse gulden',
        ],
        'SSP' => [
            0 => 'SSP',
            1 => 'Zuid-Soedanees pond',
        ],
        'STD' => [
            0 => 'STD',
            1 => 'Santomese dobra (1977–2017)',
        ],
        'STN' => [
            0 => 'STN',
            1 => 'Santomese dobra',
        ],
        'SUR' => [
            0 => 'SUR',
            1 => 'Sovjet-roebel',
        ],
        'SVC' => [
            0 => 'SVC',
            1 => 'Salvadoraanse colón',
        ],
        'SYP' => [
            0 => 'SYP',
            1 => 'Syrisch pond',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'Swazische lilangeni',
        ],
        'THB' => [
            0 => '฿',
            1 => 'Thaise baht',
        ],
        'TJR' => [
            0 => 'TJR',
            1 => 'Tadzjikistaanse roebel',
        ],
        'TJS' => [
            0 => 'TJS',
            1 => 'Tadzjiekse somoni',
        ],
        'TMM' => [
            0 => 'TMM',
            1 => 'Turkmeense manat (1993–2009)',
        ],
        'TMT' => [
            0 => 'TMT',
            1 => 'Turkmeense manat',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'Tunesische dinar',
        ],
        'TOP' => [
            0 => 'TOP',
            1 => 'Tongaanse paʻanga',
        ],
        'TPE' => [
            0 => 'TPE',
            1 => 'Timorese escudo',
        ],
        'TRL' => [
            0 => 'TRL',
            1 => 'Turkse lire',
        ],
        'TRY' => [
            0 => 'TRY',
            1 => 'Turkse lira',
        ],
        'TTD' => [
            0 => 'TTD',
            1 => 'Trinidad en Tobago-dollar',
        ],
        'TWD' => [
            0 => 'NT$',
            1 => 'Nieuwe Taiwanese dollar',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'Tanzaniaanse shilling',
        ],
        'UAH' => [
            0 => 'UAH',
            1 => 'Oekraïense hryvnia',
        ],
        'UAK' => [
            0 => 'UAK',
            1 => 'Oekraïense karbovanetz',
        ],
        'UGS' => [
            0 => 'UGS',
            1 => 'Oegandese shilling (1966–1987)',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'Oegandese shilling',
        ],
        'USD' => [
            0 => 'US$',
            1 => 'Amerikaanse dollar',
        ],
        'USN' => [
            0 => 'USN',
            1 => 'Amerikaanse dollar (volgende dag)',
        ],
        'USS' => [
            0 => 'USS',
            1 => 'Amerikaanse dollar (zelfde dag)',
        ],
        'UYI' => [
            0 => 'UYI',
            1 => 'Uruguayaanse peso en geïndexeerde eenheden',
        ],
        'UYP' => [
            0 => 'UYP',
            1 => 'Uruguayaanse peso (1975–1993)',
        ],
        'UYU' => [
            0 => 'UYU',
            1 => 'Uruguayaanse peso',
        ],
        'UYW' => [
            0 => 'UYW',
            1 => 'Uruguayaanse nominale salarisindexeenheid',
        ],
        'UZS' => [
            0 => 'UZS',
            1 => 'Oezbeekse sum',
        ],
        'VEB' => [
            0 => 'VEB',
            1 => 'Venezolaanse bolivar (1871–2008)',
        ],
        'VED' => [
            0 => 'VED',
            1 => 'Bolívar Soberano',
        ],
        'VEF' => [
            0 => 'VEF',
            1 => 'Venezolaanse bolivar (2008–2018)',
        ],
        'VES' => [
            0 => 'VES',
            1 => 'Venezolaanse bolivar',
        ],
        'VND' => [
            0 => '₫',
            1 => 'Vietnamese dong',
        ],
        'VNN' => [
            0 => 'VNN',
            1 => 'Vietnamese dong (1978–1985)',
        ],
        'VUV' => [
            0 => 'VUV',
            1 => 'Vanuatuaanse vatu',
        ],
        'WST' => [
            0 => 'WST',
            1 => 'Samoaanse tala',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'CFA-frank',
        ],
        'XCD' => [
            0 => 'EC$',
            1 => 'Oost-Caribische dollar',
        ],
        'XEU' => [
            0 => 'XEU',
            1 => 'European Currency Unit',
        ],
        'XFO' => [
            0 => 'XFO',
            1 => 'Franse gouden franc',
        ],
        'XFU' => [
            0 => 'XFU',
            1 => 'Franse UIC-franc',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'CFA-franc BCEAO',
        ],
        'XPF' => [
            0 => 'XPF',
            1 => 'CFP-frank',
        ],
        'XRE' => [
            0 => 'XRE',
            1 => 'RINET-fondsen',
        ],
        'YDD' => [
            0 => 'YDD',
            1 => 'Jemenitische dinar',
        ],
        'YER' => [
            0 => 'YER',
            1 => 'Jemenitische rial',
        ],
        'YUD' => [
            0 => 'YUD',
            1 => 'Joegoslavische harde dinar',
        ],
        'YUM' => [
            0 => 'YUM',
            1 => 'Joegoslavische noviy-dinar',
        ],
        'YUN' => [
            0 => 'YUN',
            1 => 'Joegoslavische convertibele dinar',
        ],
        'YUR' => [
            0 => 'YUR',
            1 => 'Joegoslavische hervormde dinar (1992–1993)',
        ],
        'ZAL' => [
            0 => 'ZAL',
            1 => 'Zuid-Afrikaanse rand (financieel)',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'Zuid-Afrikaanse rand',
        ],
        'ZMK' => [
            0 => 'ZMK',
            1 => 'Zambiaanse kwacha (1968–2012)',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'Zambiaanse kwacha',
        ],
        'ZRN' => [
            0 => 'ZRN',
            1 => 'Zaïrese nieuwe zaïre',
        ],
        'ZRZ' => [
            0 => 'ZRZ',
            1 => 'Zaïrese zaïre',
        ],
        'ZWD' => [
            0 => 'ZWD',
            1 => 'Zimbabwaanse dollar',
        ],
        'ZWL' => [
            0 => 'ZWL',
            1 => 'Zimbabwaanse dollar (2009)',
        ],
        'ZWR' => [
            0 => 'ZWR',
            1 => 'Zimbabwaanse dollar (2008)',
        ],
    ],
];
